@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2007 Jari-Matti Mäkelä <jmjm@iki.fi>                    *
- *   copyright (C) 2008-2014                                               *
+ *   copyright (C) 2008-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -32,6 +32,7 @@
  * Constructor, initialises a couple of variables.
  */
 DWriter::DWriter()
+  : isInterface(false)
 {
     startline = m_endl + m_indentation;
 }
@@ -82,7 +83,7 @@ void DWriter::writeModuleImports(UMLClassifier *c, QTextStream &d)
     UMLPackageList imports;
     findObjectsRelated(c, imports);
     foreach (UMLPackage* con, imports) {
-        if (con->baseType() == UMLObject::ot_Datatype)
+        if (con->isUMLDatatype())
             continue;
         QString pkg = con->package();
         if (!pkg.isEmpty() && pkg != c->package())
@@ -125,7 +126,7 @@ void DWriter::writeClass(UMLClassifier *c)
     // open text stream to file
     QTextStream d(&file);
 
-    //try to find a heading file (license, coments, etc)
+    //try to find a heading file (license, comments, etc)
     QString str;
     str = getHeadingFile(QLatin1String(".d"));
     if (!str.isEmpty()) {
@@ -141,7 +142,7 @@ void DWriter::writeClass(UMLClassifier *c)
     writeModuleImports(c, d);
 
     // write the opening declaration for the class incl any documentation,
-    // interfaces and/or inheritence issues we have
+    // interfaces and/or inheritance issues we have
     writeClassDecl(c, d);
 
     // start body of class
@@ -499,7 +500,7 @@ void DWriter::writeAssociationDecls(UMLAssociationList associations, Uml::ID::Ty
             if (a->getObjectId(Uml::RoleType::B) == id)
                 printRoleA = true;
 
-            // First: we insert documentaion for association IF it has either role AND some documentation (!)
+            // First: we insert documentation for association IF it has either role AND some documentation (!)
             if ((printRoleA || printRoleB) && !(a->doc().isEmpty()))
                 writeComment(a->doc(), m_indentation, d);
 
@@ -706,7 +707,7 @@ void DWriter::writeConstructor(UMLClassifier *c, QTextStream &d)
 }
 
 // IF the type is "string" we need to declare it as
-// the D Object "String" (there is no string primative in D).
+// the D Object "String" (there is no string primitive in D).
 // Same thing again for "bool" to "boolean"
 QString DWriter::fixTypeName(const QString& string)
 {
@@ -761,7 +762,7 @@ QStringList DWriter::defaultDatatypes()
 
 bool DWriter::compareDMethod(UMLOperation *op1, UMLOperation *op2)
 {
-    if (op1 == NULL || op2 == NULL)
+    if (op1 == 0 || op2 == 0)
         return false;
     if (op1 == op2)
         return true;
