@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2005-2014                                               *
+ *   copyright (C) 2005-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -29,7 +29,7 @@ class QMimeData;
 /**
  * Utilities for code import
  * @author Oliver Kellogg
- * Bugs and comments to umbrello-devel@kde.org or http://bugs.kde.org
+ * Bugs and comments to umbrello-devel@kde.org or https://bugs.kde.org
  */
 namespace Import_Utils {
 
@@ -53,6 +53,8 @@ namespace Import_Utils {
                                bool searchInParentPackageOnly = false,
                                bool remapParent = true);
 
+    UMLObject* createUMLObjectHierarchy(UMLObject::ObjectType type, const QString &name, UMLPackage *parentPkg);
+
     void putAtGlobalScope(bool yesno);
 
     void setRelatedClassifier(UMLClassifier *c);
@@ -101,6 +103,8 @@ namespace Import_Utils {
 
     bool isDatatype(const QString& name, UMLPackage *parentPkg = 0);
 
+    UMLPackage *globalScope();
+
 } // end namespace Import_Utils
 
 #endif
